@@ -19,6 +19,10 @@ my %Perlito_internal_module = (
     # constant => 'Perlito5::constant',
 );
 
+sub register_internal_module {
+    my ($module, $real_name) = @_;
+    $Perlito_internal_module{$module} = $real_name;
+}
 
 token use_decl { 'use' | 'no' };
 
@@ -184,10 +188,9 @@ sub parse_time_eval {
     # and create a syntax tree
     # TODO: the module should run in a new scope
     #   without access to the current lexical variables
-    my $comp_units = [];
 
     if ( !$Perlito5::EXPAND_USE ) {
-        expand_use($comp_units, $ast);
+        expand_use($ast);
     }
 
     if ( $Perlito5::EXPAND_USE ) {
@@ -227,18 +230,11 @@ sub parse_time_eval {
         }
     }
 
-    if (@$comp_units) {
-        # TODO - move @comp_units to top-level of the AST
-        return Perlito5::AST::Block->new( stmts => $comp_units );
-    }
-    else {
-        # when seeing "use" a second time, no further code is generated
-        return Perlito5::AST::Apply->new(
-            code      => 'undef',
-            namespace => '',
-            arguments => []
-        );
-    }
+    return Perlito5::AST::Apply->new(
+        code      => 'undef',
+        namespace => '',
+        arguments => []
+    );
 }
 
 sub emit_time_eval {
@@ -281,7 +277,6 @@ sub filename_lookup {
 }
 
 sub expand_use {
-    my $comp_units = shift;
     my $stmt = shift;
 
     my $module_name = $stmt->mod;
@@ -323,7 +318,7 @@ sub expand_use {
 
     if ($ENV{PERLITO5DEV}) {
         # "new BEGIN"
-        push @$comp_units,
+        push @Perlito5::COMP_UNIT,
             Perlito5::AST::CompUnit->new(
                 name => 'main',
                 body => Perlito5::Match::flat($m),
@@ -332,40 +327,27 @@ sub expand_use {
     }
 
     # "old BEGIN"
-    push @$comp_units, @{ add_comp_unit(
-        [
-            Perlito5::AST::CompUnit->new(
-                name => 'main',
-                body => Perlito5::Match::flat($m),
-            )
-        ]
-    ) };
+    add_comp_unit(
+        Perlito5::AST::CompUnit->new(
+            name => 'main',
+            body => Perlito5::Match::flat($m),
+        ),
+    );
     return;
 }
 
 sub add_comp_unit {
     # TODO - this subroutine is obsolete
-    my $parse = shift;
-    my $comp_units = [];
+    my $comp_unit = shift;
 
-    for my $comp_unit (@$parse) {
-        if (defined $comp_unit) {
-            if ($comp_unit->isa('Perlito5::AST::Use')) {
-                expand_use($comp_units, $comp_unit);
-            }
-            elsif ($comp_unit->isa('Perlito5::AST::CompUnit')) {
-                # warn "parsed comp_unit: '", $comp_unit->name, "'";
-                for my $stmt (@{ $comp_unit->body }) {
-                    if ($stmt->isa('Perlito5::AST::Use')) {
-                        expand_use($comp_units, $stmt);
-                    }
-                }
-            }
-            push @$comp_units, $comp_unit;
-            # say "comp_unit done";
+    # warn "parsed comp_unit: '", $comp_unit->name, "'";
+    for my $stmt (@{ $comp_unit->body }) {
+        if ($stmt->isa('Perlito5::AST::Use')) {
+            expand_use($stmt);
         }
     }
-    return $comp_units;
+    push @Perlito5::COMP_UNIT, $comp_unit;
+    # say "comp_unit done";
 }
 
 sub require {
